#' Internal pins board
#'
#' Pins board used internally to manage download, reading, and caching of data
#' sets.
#'
#' @return a pins board
#'
#' @examples
#' internal_board()
#'
#' @export
internal_board <- function() {
  modeldatatoo_board()
}
